==> minuet-18.11.80.tar.xz: minuet-18.11.80/src/interfaces/iexercisecontroller.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 by Sandro S. Andrade <sandroandrade@kde.org>
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License as
** published by the Free Software Foundation; either version 2 of
** the License or (at your option) version 3 or any later version
** accepted by the membership of KDE e.V. (or its successor approved
** by the membership of KDE e.V.), which shall act as a proxy
** defined in Section 14 of version 3 of the license.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
**
****************************************************************************/

#include "iexercisecontroller.h"

#include <qqml.h>

namespace Minuet
{

IExerciseController::IExerciseController(QObject *parent)
    : QObject(parent)
{
    qmlRegisterInterface<IExerciseController>("IExerciseController");
}

IExerciseController::~IExerciseController()
{
}

void IExerciseController::setCurrentExercise(QVariantMap currentExercise)
{
    if (m_currentExercise != currentExercise) {
        m_currentExercise = currentExercise;
        m_selectedExerciseOptions = QJsonArray();
        emit currentExerciseChanged(m_currentExercise);
    }
}

QJsonArray IExerciseController::selectedExerciseOptions() const
{
    return m_selectedExerciseOptions;
}

}

==> minuet-21.12.1.tar.xz: minuet-21.12.1/src/interfaces/iexercisecontroller.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 by Sandro S. Andrade <sandroandrade@kde.org>
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License as
** published by the Free Software Foundation; either version 2 of
** the License or (at your option) version 3 or any later version
** accepted by the membership of KDE e.V. (or its successor approved
** by the membership of KDE e.V.), which shall act as a proxy
** defined in Section 14 of version 3 of the license.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
**
****************************************************************************/

#include "iexercisecontroller.h"

#include <qqml.h>

namespace Minuet
{
IExerciseController::IExerciseController(QObject *parent) : QObject(parent)
{
    qmlRegisterInterface<IExerciseController>("IExerciseController");
}

void IExerciseController::setCurrentExercise(QVariantMap currentExercise)
{
    if (m_currentExercise != currentExercise) {
        m_currentExercise = currentExercise;
        m_selectedExerciseOptions = QJsonArray();
        emit currentExerciseChanged(m_currentExercise);
    }
}

QJsonArray IExerciseController::selectedExerciseOptions() const
{
    return m_selectedExerciseOptions;
}

}
